//****c* XTools/XEvents
// NAME
//    XEvents
//
// DESCRIPTION
//    Configura uma ação a ser executada quando ocorrer um determinado evento em um objeto.
//
// AUTHOR
//    Rodrigo Souza dos Santos
//    |html <br /><a href="mailto:%72%6f%64%72%69%67%6f%2e%73%6f%75%7a%61%40%63%65%6c%65%70%61%72%2e%70%72%2e%67%6f%76%2e%62%72">&#114;&#111;&#100;&#114;&#105;&#103;&#111;&#46;&#115;&#111;&#117;&#122;&#97;&#64;&#99;&#101;&#108;&#101;&#112;&#97;&#114;&#46;&#112;&#114;&#46;&#103;&#111;&#118;&#46;&#98;&#114;</a>
//    |html <br /><a href="mailto:%72%6f%64%72%69%67%6f%73%6f%75%7a%61%64%6f%73%73%61%6e%74%6f%73%40%67%6d%61%69%6c%2e%63%6f%6d">&#114;&#111;&#100;&#114;&#105;&#103;&#111;&#115;&#111;&#117;&#122;&#97;&#100;&#111;&#115;&#115;&#97;&#110;&#116;&#111;&#115;&#64;&#103;&#109;&#97;&#105;&#108;&#46;&#99;&#111;&#109;</a>
//
//******
// You can use this space for remarks that should not be included
// in the documentation.
//
( function( )
{
	//****im* XEvents/config
	// NAME
	//    config
	//
	// DESCRIPTION
	//    Configura ( adiciona ou remove ) uma ação a um objeto ( node ).
	//
	// SYNOPSIS
	function config( pObj, pEvent, pHandler )
	// INPUTS
	//    pObj     :
	//    pEvent   :
	//    pHandler :
	//
	// SOURCE
	{
		if ( typeof pObj == 'object' )
		{
			if ( pEvent.substring( 0, 2 ) == 'on' )
				pEvent = pEvent.substring( 2, pEvent.length );

			if ( arguments.length == 3 )
			{
				if ( pObj.addEventListener )
					pObj.addEventListener( pEvent, pHandler, false );
				else if ( pObj.attachEvent )
					pObj.attachEvent( 'on' + pEvent, pHandler );

				( arguments[ 0 ].preventDefault ) ?
					arguments[ 0 ].preventDefault( ) : arguments[ 0 ].returnValue = false;
			}
			else if ( arguments.length == 4 )
			{
				if ( pObj.removeEventListener )
					pObj.removeEventListener( pEvent, pHandler, false );
				else if ( pObj.detachEvent )
					pObj.detachEvent( 'on' + pEvent, pHandler );
			}
		}
	}
	//
	// NOTES
	//    Ações anônimas não podem ser removidas
	//
	//******

	//****m* XEvents/add
	// NAME
	//    add
	//
	// DESCRIPTION
	//    Adiciona uma ação a um objeto ( node ).
	//
	// SYNOPSIS
	function add( pObj, pEvent, pHandler )
	// INPUTS
	//    pObj     :
	//    pEvent   :
	//    pHandler :
	//
	{
		config( pObj, pEvent, pHandler );
	}
	//
	// NOTES
	//    Ações anônimas não podem ser removidas
	//
	// EXAMPLE
	//    function myHandler( )
	//    {
	//        /*do something*/
	//    }
	//
	//    XEvents.add( node, 'onclick', myHandler );
	//
	//    XEvents.add( node, "onclick", function( )
	//    {
	//        /*do something*/
	//    } );
	//
	//******

	//****m* XEvents/remove
	// NAME
	//    remove
	//
	// DESCRIPTION
	//    Remove a ação de um objeto ( node ).
	//
	// SYNOPSIS

	function remove( pObj, pEvent, pHandler )
	// INPUTS
	//    pObj     :
	//    pEvent   :
	//    pHandler :
	//
	{
		config( pObj, pEvent, pHandler, true );
	}
	//
	// NOTES
	//    Ações anônimas não podem ser removidas
	//
	// EXAMPLE
	//    XEvents.remove( node, 'onclick', myHandler );
	//
	//******

	function Events( )
	{
	}

	Events.prototype.add = add;
	Events.prototype.remove = remove;

	window.XEvents = new Events;
} )( );
